/*
 * @Author: Dwt 
 * @Date: 2019-11-11 15:50:23 
 * @Last Modified by: Dwt
 * @Last Modified time: 2019-11-11 21:59:14
 */

import 'dart:io';

import 'package:flutter/material.dart';
import 'package:camera_custom/camera_custom.dart';
import 'package:camera/camera.dart';

class CameraCustomExample extends StatefulWidget {

  @override
  _CameraCustomExampleState createState() => _CameraCustomExampleState();
}

class _CameraCustomExampleState extends State<CameraCustomExample> {
  String imagePath;
  Widget image;
  double headerHeight = 320.0;
  final String assetImagePath = 'images/camera_custom_no_image.png';

  List<CameraDescription> cameras;

  @override
  void initState() {
    // TODO: implement initState
    getAvailableCameras();

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: Text('自定义相机'),
        ),
        body: Column(
          children: <Widget>[
            _getImageFromFile(imagePath),
            // imagePath != null
            //     ? _getImageFromFile(imagePath)
            //     : _getImageFromAsset(),
            //获取相机按钮
            _setupCameraButton(context),
            // _getLogo(),
          ],
        ));
  }

  //设置相机按钮
  Widget _setupCameraButton(BuildContext context) {
    return Center(
      child: FloatingActionButton(
        onPressed: () {
          if (cameras != null) {
            _openCamera(context);
          } else {
            getAvailableCameras();
            print('没有可用的摄像头');
          }
        },
        child: Icon(
          Icons.photo_camera,
          color: Colors.white,
        ),
        backgroundColor: Colors.green,
      ),
    );
  }

  //获取选取文件路径
  Widget _getImageFromFile(String imagePath) {
    if (imagePath == null) {
      return Container();
    }
    
    return Center(
      child: Image.file(
      File(imagePath),
      fit: BoxFit.cover,
      width: double.infinity,
      height: headerHeight,
    ));
  }

  //无图片展示
  Widget _getImageFromAsset() {
    return Center(
      child: Container(
        width: double.infinity,
        height: headerHeight,
        color: Colors.grey,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Image.asset(
              assetImagePath,
              width: 60.0,
              height: 60.0,
            ),
            Container(
              margin: EdgeInsets.only(top: 8.0),
              child: Text('没有可用的图片',
                  style: TextStyle(color: Colors.grey[350], fontSize: 15.0)),
            )
          ],
        ),
      ),
    );
  }

  //跳转相机
  Future _openCamera(BuildContext context) async {
    final tImagePath =
      await Navigator.push(context, new MaterialPageRoute(builder: (context) {
      return CameraCustomPage(cameras);
    }));
    setState(() {
      imagePath = tImagePath;
    });

    if (tImagePath != null) {
      print("$tImagePath");

      image = Image.file(
        File(tImagePath),
        height: headerHeight,
        width: double.infinity,
        fit: BoxFit.cover,
      );
    }
  }

  Widget _getLogo() {
    return Container(
      margin: EdgeInsets.only(top: 200.0),
      alignment: Alignment.center,
      child: Center(
        child: Image.asset(
          '',
          width: 160.0,
          height: 160.0,
          fit: BoxFit.contain,
        ),
      ),
    );
  }

  //获取可用摄像头
  Future<Null> getAvailableCameras() async {
    try {
      cameras = await availableCameras();
    } on CameraException catch (e) {
      // logError(e.code, e.description);
    }
  }
}
